<?php

namespace Drupal\uber_affiliate\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;
use Drupal\core\Database;
use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Component\Utility\Xss;
use Drupal\Component\Utility\UrlHelper;


/**
 * Affiliate Overview page class.
 */
class UberAffiliate extends  ControllerBase {

  /**
   * Admin overview page method.
   */
  public function affiliate_admin_overviewpage() {

    $payouts_symbol = '';
    $payouts_symbol_pos = '';

    $database = \Drupal::database();
    $query = $database->select('affiliate', 'a');
    $query->innerjoin('users_field_data', 'u');
    $query->condition('u.uid',  0, '<>');
    $query->fields('u', ['uid', 'name', 'status', 'created', 'access']);
    $query->range(0, 50);
    $result = $query->execute();

    $rows = array();

    foreach ($result as $affiliate) {
      $affiliate_uid = $affiliate->uid;
      $affiliate_name = SafeMarkup::checkPlain($affiliate->name);
      $affiliate_uid_display =  l($affiliate_uid, \Drupal::service('path.alias_manager')->getAliasByPath('user/' . $affiliate_uid));
      $affiliate_name_display =  l($affiliate_name, \Drupal::service('path.alias_manager')->getAliasByPath('user/' . $affiliate_uid));
      $affiliate_active = $affiliate->active ? t('Yes') : t('No');
      $affiliate_created = format_date($affiliate->created);
      $payouts_owed_display = $payouts_symbol . $affiliate->payouts_owed;
      $payouts_paid_display = $payouts_symbol . $affiliate->payouts_paid;
      $payouts_form = '';
      if ($payouts_symbol_pos == 2) {
        $payouts_owed_display = $affiliate->payouts_owed . $payouts_symbol;
        $payouts_paid_display = $affiliate->payouts_paid . $payouts_symbol;
      }
      if (user_access('administer affiliate settings') || user_access('administer affiliate payouts')) {
        $payouts_form .= drupal_render(drupal_get_form('affiliate_payout_inlineform', $affiliate_uid));
      }
      $rows[] = array($affiliate_uid_display, $affiliate_name_display, $affiliate_active, $affiliate_created, $affiliate->clicks, $affiliate->referrals, $payouts_owed_display, $payouts_paid_display, $payouts_form);
    }

    $header = [
      'title' => t('ID'),
      'name' => t('Name'),
      'active' => t('Active'),
      'created' => t('Created'),
      'clicks' => t('Clicks'),
      'referrals' => t('Referrals'),
      'payouts_owed' => t('Payouts owed'),
      'payouts_paid' => t('Payouts paid'),
    ];

    $build['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => t('No content has been found.'),
    ];
    return [
      '#type' => '#markup',
      '#markup' => render($build)
    ];

  }

  /**
   * The primary tracking of the affiliate and the main affiliate link.
   * @todo
   *   Have this function checked by security team if possible, or if not, get a second opinion just to be sure.
   */
  public function affiliate_page($aff_id, $dest_path, $tracker_id) {
    $allow_all_paths = \Drupal::state()->get('affiliate_module_allow_all_paths', 0);
    $allow_all_node_types = \Drupal::state()->get('affiliate_module_allow_all_node_types', 0);



    $affid =  (int) Xss::filter($aff_id);
    $path_given = $dest_path;
    $tracker = (int) Xss::filter($tracker_id);



    // Note to self: ask a security guru about this.
    $path_arg = UrlHelper::stripDangerousProtocols(implode('/', explode('|', rawurldecode($path_given))));

    $verify_node_type = FALSE;
    if (!$allow_all_node_types) {
      $verify_node_type = TRUE;
    }
    if ($allow_all_paths) {
      $verify_node_type = FALSE;
    }

    if (!isset($tracker) || empty($tracker)) {
      $tracker = 0;
    }
    if (!isset($affid) || empty($affid)) {
      $affid = 1;
    }

    // Send invalid clicks to the front page if no path argument is supplied.
    if (!isset($path_arg) || empty($path_arg)) {
      $path = base_path();
    }
    else {
      $path = $path_arg;
    }

    // Path aliases will fail validation... Convert to normal path before validating.
    $path_normal = \Drupal::service('path_alias.manager')->getPathByAlias($path);



    // This seems like it could be written better...?
    if (affiliate_validate_click($affid, $path_normal, $verify_node_type)) {
      $campaign_id = affiliate_get_campaign_id($path_normal);
      affiliate_add_click($affid, $campaign_id);
    }
    $destination_is_valid = affiliate_valid_destination($path_normal);

    // Empty will simply take us to the front page, in case the path doesn't validate.
    $destination_actual = '';
    if ($destination_is_valid) {
      $destination_actual = \Drupal::service('path_alias.manager')->getPathByAlias($path_normal);
    }

    // Unnecessary check_url()? Better safe than sorry...
    $destination_actual =  UrlHelper::stripDangerousProtocols($destination_actual);

    // At minimum, if all validations fail, we'll be taken to the front page. If the path
    // given is valid though, we'll be taken to that path either way, regardless of whether
    // the affiliate was credited with a valid click-thru.
    if (empty($destination_actual)) {
      $language = \Drupal::languageManager()->getLanguage('vi');
      $url = Url::fromRoute('<front>', [], ['language' => $language]);
      return new RedirectResponse($url->toString());

    }
    return new RedirectResponse(\Drupal\Core\Url::fromRoute($destination_actual)->toString());
  }
}
