<?php

namespace Drupal\uber_affiliate\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * PayoutForm.
 */
class PayoutForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'uber_affiliate.payout.settings';

  /**
   * Required by FormBase.
   */
  public function getFormId() {
    return 'uber_affiliate_payout_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * PayoutForm.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $userpoints_form_collapse = \Drupal::moduleHandler()->moduleExists('userpoints') ? FALSE : TRUE;
    $userpoints_disabled = \Drupal::moduleHandler()->moduleExists('userpoints') ? FALSE : TRUE;
    $userpoints_options = function_exists('userpoints_get_categories') ? userpoints_get_categories() : array(0 => t('No categories available'));
    $referral_form_collapse = \Drupal::moduleHandler()->moduleExists('referral') ? FALSE : TRUE;

    $form['affiliate_module_settings']['payouts'] = array(
      '#type' => 'fieldset',
      '#title' => t('Payouts'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );
    $form['affiliate_module_settings']['payouts']['affiliate_module_payouts_symbol'] = array(
      '#type' => 'textfield',
      '#title' => t('Currency symbol'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_symbol', '$'),
      '#description' => t('Enter the symbol used to denote money in your locale. Example: in the US, France, and the UK, the symbols are typically <b>&dollar;</b>, <b>&euro;</b> and <b>&pound;</b>, respectively.'),
      '#size' => 1,
    );
    $form['affiliate_module_settings']['payouts']['affiliate_module_payouts_symbol_placement'] = array(
      '#type' => 'select',
      '#title' => t('Currency symbol placement'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_symbol_placement', 1),
      '#options' => array(1 => t('Before'), 2 => t('After')),
      '#description' => t('Select whether the currency symbol should be displayed before or after the amount.'),
    );
    $form['affiliate_module_settings']['payouts']['affiliate_module_payouts_per_click'] = array(
      '#type' => 'textfield',
      '#title' => t('Payouts per click'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_per_click', 0.00),
      '#description' => t('Enter the amount, using a decimal point as the separator, that each affiliate will receive per click. For example, if the amount is &dollar;0.50 enter <b>0.50</b> in the box. Or, if the amount is 1,07&euro; enter <b>1.07</b> in the box.'),
    );
    $form['affiliate_module_settings']['payouts']['referral'] = array(
      '#type' => 'fieldset',
      '#title' => t('Referrals'),
      '#collapsible' => TRUE,
      '#collapsed' => $referral_form_collapse,
    );
    $form['affiliate_module_settings']['payouts']['referral']['affiliate_module_payouts_per_referral'] = array(
      '#type' => 'textfield',
      '#title' => t('Payouts per referral'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_per_referral', 0.00),
      '#description' => t('Enter the amount, using a decimal point as the separator, that each affiliate will receive per referral. For example, if the amount is &dollar;0.50 enter <b>0.50</b> in the box. Or, if the amount is 1,07&euro; enter <b>1.07</b> in the box. <b>Note: this setting has no effect if the <a href="http://drupal.org/project/referral">Referral</a> module is not installed</b>.'),
    );
    $form['affiliate_module_settings']['payouts']['userpoints'] = array(
      '#type' => 'fieldset',
      '#title' => t('Userpoints'),
      '#collapsible' => TRUE,
      '#collapsed' => $userpoints_form_collapse,
    );
    $form['affiliate_module_settings']['payouts']['userpoints']['affiliate_module_payouts_userpoints_clicks'] = array(
      '#type' => 'textfield',
      '#title' => t('Points per click'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_userpoints_clicks', 0),
      '#description' => t('Enter the number of points each affiliate will receive per click. <b>Note: this setting has no effect if the <a href="http://drupal.org/project/userpoints">Userpoints</a> module is not installed</b>.'),
      '#size' => 1,
      '#disabled' => $userpoints_disabled,
    );
    $form['affiliate_module_settings']['payouts']['userpoints']['affiliate_module_payouts_userpoints_tid'] = array(
      '#type' => 'select',
      '#title' => t('Category'),
      '#default_value' => \Drupal::state()->get('affiliate_module_payouts_userpoints_tid', 0),
      '#options' => $userpoints_options,
      '#description' => t('Points for affilate click-thrus will be assigned to this category. <b>Note: this setting has no effect if the <a href="http://drupal.org/project/userpoints">Userpoints</a> module is not installed</b>.'),
      '#disabled' => $userpoints_disabled,
    );

    return $form;

  }


  /**
   * Required by FormBase.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Required by FormBase.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

}
