<?php

namespace Drupal\uber_affiliate\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Link;

/**
 * Displays the top affiliates.
 *
 * @Block(
 *   id = "uber_affiliate_top_users",
 *   admin_label = @Translation("Top Affiliates"),
 * )
 */
class UberAffiliateBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    // Todo check permissions if user_access('view affiliate overviews') || user_access('administer affiliate settings') || user_access('view any affiliate info')) {
    //  Then call affiliate_top_users_block_content();
    return $this->affiliate_top_users_block_content();
  }

  /**
   * Return block dataa
   */
  private function affiliate_top_users_block_content() {
    $limit = \Drupal::state()->get('affiliate_module_top_users_count_block', 10);
    $time = time();
    $time_interval = \Drupal::state()->get('affiliate_module_top_users_period_interval', 259200);
    $time_limit = $time - $time_interval;
   // $results = \Drupal::database()->query("SELECT COUNT(DISTINCT(ac.clickid)) AS clicks, u.uid AS uid, u.name AS name, u.data AS data, aa.payouts_owed AS payouts_owed
    // FROM {affiliate_clicks} ac INNER JOIN {users} u ON ac.uid = u.uid INNER JOIN {affiliate} aa ON u.uid = aa.uid WHERE aa.active = 1 AND ac.click_time > :time_limit
    // GROUP BY uid ORDER BY clicks DESC", array(":time_limit" => $time_limit));
    $database = \Drupal::database();
    $query = $database->select('affiliate_clicks', 'ac');
    $query->innerjoin('users_field_data', 'u');
    $query->innerjoin('affiliate', 'aa');
    $query->condition('u.uid', 'aa.uid', '=');
    $query->condition('u.uid', 'ac.uid', '=');
    $query->condition('aa.active', 1, '=');
    $query->condition('ac.click_time', $time_limit, '>');
    $query->fields('u', ['uid', 'name']);
    $query->fields('aa', ['payouts_owed']);
    $results = $query->execute();

    $results_count = count($results);
    $rows = array();
    $rank = 1;
    if ($results && !empty($results)) {
      foreach ($results as $result) {
        $userdata = unserialize($result->data);
        $homepage = (isset($userdata['affiliate_homepage']) && !empty($userdata['affiliate_homepage'])) ? check_url($userdata['affiliate_homepage']) : '';
        $username = SafeMarkup::checkPlain($result->name);
        $name = (!empty($homepage)) ? Link::fromTextAndUrl($username, $homepage) : Link::fromTextAndUrl($username,  \Drupal::service('path.alias_manager')->getAliasByPath('user/' . $result->uid));
        $rows[] = array(
          array('data' => t('#@rank', array('@rank' => $rank++))),
          array('data' => $name),
        );

      }
    }
    if (empty($rows)) {
      $rows[] = array(array('data' => t('No affiliate activity found for this time period.'), 'colspan' => '2'));
    }

    $output = [
      '#theme' => 'table',
      '#rows' => $rows,
    ];

    if ($results_count && $results_count > $limit) {
      $output .= [
        '#theme' => 'more_link',
        array('url' => \Drupal::service('path.alias_manager')->getAliasByPath('affiliate/top-users'), 'title' => t('More')),
      ];
    }
    return $output;
  }

}
